@@ -1,11 +1,15 @@
 from dagster import check
 from dagster.core.host_representation import PipelineSelector, RepositoryLocation
 from dagster.core.host_representation.external import ExternalPipeline
+from dagster.core.host_representation.grpc_server_state_subscriber import (
+    LocationStateChangeEventType,
+    LocationStateSubscriber,
+)
 from dagster.core.instance import DagsterInstance
-from dagster.grpc.types import ScheduleExecutionDataMode
 from dagster_graphql.implementation.utils import UserFacingGraphQLError
 from dagster_graphql.schema.errors import DauphinInvalidSubsetError
 from dagster_graphql.schema.pipelines import DauphinPipeline
+from rx.subjects import Subject
 
 
 class DagsterGraphQLContext:
@@ -13,16 +17,25 @@ class DagsterGraphQLContext:
         self._instance = check.inst_param(instance, "instance", DagsterInstance)
         self._workspace = workspace
         self._repository_locations = {}
+
+        self._location_state_events = Subject()
+        self._location_state_subscriber = LocationStateSubscriber(
+            self._location_state_events_handler
+        )
+
         for handle in self._workspace.repository_location_handles:
             check.invariant(
                 self._repository_locations.get(handle.location_name) is None,
-                'Can not have multiple locations with the same name, got multiple "{name}"'.format(
+                'Cannot have multiple locations with the same name, got multiple "{name}"'.format(
                     name=handle.location_name,
                 ),
             )
+
+            handle.add_state_subscriber(self._location_state_subscriber)
             self._repository_locations[handle.location_name] = RepositoryLocation.from_handle(
                 handle
             )
+
         self.version = version
 
     @property
@@ -33,18 +46,58 @@ class DagsterGraphQLContext:
     def repository_locations(self):
         return list(self._repository_locations.values())
 
+    @property
+    def repository_location_names(self):
+        return self._workspace.repository_location_names
+
+    @property
+    def location_state_events(self):
+        return self._location_state_events
+
+    def _location_state_events_handler(self, event):
+        # If the server was updated or we were not able to reconnect, we immediately reload the
+        # location handle
+        if event.event_type in (
+            LocationStateChangeEventType.LOCATION_UPDATED,
+            LocationStateChangeEventType.LOCATION_ERROR,
+        ):
+            # In case of an updated location, reload the handle to get updated repository data and
+            # re-attach a subscriber
+            # In case of a location error, just reload the handle in order to update the workspace
+            # with the correct error messages
+            self.reload_repository_location(event.location_name)
+
+        self._location_state_events.on_next(event)
+
+    def repository_location_errors(self):
+        return self._workspace.repository_location_errors
+
     def get_repository_location(self, name):
         return self._repository_locations[name]
 
+    def has_repository_location_error(self, name):
+        return self._workspace.has_repository_location_error(name)
+
+    def get_repository_location_error(self, name):
+        return self._workspace.get_repository_location_error(name)
+
     def has_repository_location(self, name):
         return name in self._repository_locations
 
+    def is_reload_supported(self, name):
+        return self._workspace.is_reload_supported(name)
+
     def reload_repository_location(self, name):
-        new_handle = self._workspace.reload_repository_location(name)
-        new_location = RepositoryLocation.from_handle(new_handle)
-        check.invariant(new_location.name == name)
-        self._repository_locations[name] = new_location
-        return new_location
+        self._workspace.reload_repository_location(name)
+
+        if self._workspace.has_repository_location_handle(name):
+            new_handle = self._workspace.get_repository_location_handle(name)
+            new_handle.add_state_subscriber(self._location_state_subscriber)
+            new_location = RepositoryLocation.from_handle(new_handle)
+            check.invariant(new_location.name == name)
+            self._repository_locations[name] = new_location
+        elif name in self._repository_locations:
+            del self._repository_locations[name]
 
     def get_subset_external_pipeline(self, selector):
         check.inst_param(selector, "selector", PipelineSelector)
@@ -124,18 +177,6 @@ class DagsterGraphQLContext:
             repository_handle.repository_location_handle.location_name
         ].get_external_partition_names(repository_handle, partition_set_name)
 
-    def get_external_schedule_execution_data(self, repository_handle, schedule_name):
-        return self._repository_locations[
-            repository_handle.repository_location_handle.location_name
-        ].get_external_schedule_execution_data(
-            self.instance, repository_handle, schedule_name, ScheduleExecutionDataMode.PREVIEW, None
-        )
-
-    def get_external_job_param_data(self, repository_handle, job_name):
-        return self._repository_locations[
-            repository_handle.repository_location_handle.location_name
-        ].get_external_job_params(self.instance, repository_handle, job_name)
-
     def get_external_partition_set_execution_param_data(
         self, repository_handle, partition_set_name, partition_names
     ):
