@@ -85,7 +85,11 @@ def get_runs(graphene_info, filters, cursor=None, limit=None):
         if run:
             runs = [run]
     elif filters and (
-        filters.pipeline_name or filters.tags or filters.status or filters.snapshot_id
+        filters.pipeline_name
+        or filters.tags
+        or filters.statuses
+        or filters.snapshot_id
+        or filters.run_ids
     ):
         runs = instance.get_runs(filters, cursor, limit)
     else:
@@ -94,6 +98,10 @@ def get_runs(graphene_info, filters, cursor=None, limit=None):
     return [graphene_info.schema.type_named("PipelineRun")(run) for run in runs]
 
 
+def get_runs_count(graphene_info, filters):
+    return graphene_info.context.instance.get_runs_count(filters)
+
+
 def get_run_groups(graphene_info, filters=None, cursor=None, limit=None):
     from ..schema.runs import DauphinRunGroup
 
@@ -150,6 +158,7 @@ def get_execution_plan(graphene_info, selector, run_config, mode):
 @capture_dauphin_error
 def get_stats(graphene_info, run_id):
     stats = graphene_info.context.instance.get_run_stats(run_id)
+    stats.id = "stats-{run_id}"
     return graphene_info.schema.type_named("PipelineRunStatsSnapshot")(stats)
 
 
