@@ -1,12 +1,7 @@
-import yaml
 from dagster import check
-from dagster.core.host_representation import (
-    ExternalSchedule,
-    ExternalScheduleExecutionData,
-    PipelineSelector,
-    RepositorySelector,
-    ScheduleSelector,
-)
+from dagster.core.host_representation import PipelineSelector, RepositorySelector, ScheduleSelector
+from dagster.core.scheduler.job import JobStatus
+from dagster.seven import get_current_datetime_in_utc, get_timestamp_from_utc_datetime
 from graphql.execution.base import ResolveInfo
 
 from .utils import UserFacingGraphQLError, capture_dauphin_error
@@ -36,9 +31,7 @@ def start_schedule(graphene_info, schedule_selector):
         repository.get_external_schedule(schedule_selector.schedule_name)
     )
     return graphene_info.schema.type_named("ScheduleStateResult")(
-        schedule_state=graphene_info.schema.type_named("ScheduleState")(
-            graphene_info, schedule_state=schedule_state
-        )
+        graphene_info.schema.type_named("JobState")(schedule_state)
     )
 
 
@@ -48,9 +41,7 @@ def stop_schedule(graphene_info, schedule_origin_id):
     instance = graphene_info.context.instance
     schedule_state = instance.stop_schedule_and_update_storage_state(schedule_origin_id)
     return graphene_info.schema.type_named("ScheduleStateResult")(
-        schedule_state=graphene_info.schema.type_named("ScheduleState")(
-            graphene_info, schedule_state=schedule_state
-        )
+        graphene_info.schema.type_named("JobState")(schedule_state)
     )
 
 
@@ -67,61 +58,7 @@ def get_scheduler_or_error(graphene_info):
 
 
 @capture_dauphin_error
-def get_schedule_states_or_error(
-    graphene_info, repository_selector, with_no_schedule_definition_filter=None
-):
-    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
-    check.opt_inst_param(repository_selector, "repository_selector", RepositorySelector)
-    check.opt_bool_param(
-        with_no_schedule_definition_filter, "with_no_schedule_definition_filter", default=False
-    )
-
-    instance = graphene_info.context.instance
-    if not repository_selector:
-        # Return all schedule states
-        results = [
-            graphene_info.schema.type_named("ScheduleState")(
-                graphene_info, schedule_state=schedule_state
-            )
-            for schedule_state in instance.all_stored_schedule_state()
-        ]
-        return graphene_info.schema.type_named("ScheduleStates")(results=results)
-
-    location = graphene_info.context.get_repository_location(repository_selector.location_name)
-    repository = location.get_repository(repository_selector.repository_name)
-    repository_origin_id = repository.get_origin().get_id()
-    instance = graphene_info.context.instance
-
-    results = [
-        graphene_info.schema.type_named("ScheduleState")(
-            graphene_info, schedule_state=schedule_state
-        )
-        for schedule_state in instance.all_stored_schedule_state(
-            repository_origin_id=repository_origin_id
-        )
-    ]
-
-    if with_no_schedule_definition_filter:
-        external_schedules = repository.get_external_schedules()
-        external_schedule_origin_ids = set(
-            external_schedule.get_origin_id() for external_schedule in external_schedules
-        )
-
-        # Filter for all schedule states for which there are no matching external schedules with the
-        # same origin id
-        results = list(
-            filter(
-                lambda schedule_state: schedule_state.schedule_origin_id
-                not in external_schedule_origin_ids,
-                results,
-            )
-        )
-
-    return graphene_info.schema.type_named("ScheduleStates")(results=results)
-
-
-@capture_dauphin_error
-def get_schedule_definitions_or_error(graphene_info, repository_selector):
+def get_schedules_or_error(graphene_info, repository_selector):
     check.inst_param(graphene_info, "graphene_info", ResolveInfo)
     check.inst_param(repository_selector, "repository_selector", RepositorySelector)
 
@@ -130,16 +67,16 @@ def get_schedule_definitions_or_error(graphene_info, repository_selector):
     external_schedules = repository.get_external_schedules()
 
     results = [
-        graphene_info.schema.type_named("ScheduleDefinition")(
+        graphene_info.schema.type_named("Schedule")(
             graphene_info, external_schedule=external_schedule
         )
         for external_schedule in external_schedules
     ]
 
-    return graphene_info.schema.type_named("ScheduleDefinitions")(results=results)
+    return graphene_info.schema.type_named("Schedules")(results=results)
 
 
-def get_schedule_definitions_for_pipeline(graphene_info, pipeline_selector):
+def get_schedules_for_pipeline(graphene_info, pipeline_selector):
     check.inst_param(graphene_info, "graphene_info", ResolveInfo)
     check.inst_param(pipeline_selector, "pipeline_selector", PipelineSelector)
 
@@ -148,7 +85,7 @@ def get_schedule_definitions_for_pipeline(graphene_info, pipeline_selector):
     external_schedules = repository.get_external_schedules()
 
     return [
-        graphene_info.schema.type_named("ScheduleDefinition")(
+        graphene_info.schema.type_named("Schedule")(
             graphene_info, external_schedule=external_schedule
         )
         for external_schedule in external_schedules
@@ -157,7 +94,7 @@ def get_schedule_definitions_for_pipeline(graphene_info, pipeline_selector):
 
 
 @capture_dauphin_error
-def get_schedule_definition_or_error(graphene_info, schedule_selector):
+def get_schedule_or_error(graphene_info, schedule_selector):
     check.inst_param(graphene_info, "graphene_info", ResolveInfo)
     check.inst_param(schedule_selector, "schedule_selector", ScheduleSelector)
     location = graphene_info.context.get_repository_location(schedule_selector.location_name)
@@ -166,27 +103,36 @@ def get_schedule_definition_or_error(graphene_info, schedule_selector):
     external_schedule = repository.get_external_schedule(schedule_selector.schedule_name)
     if not external_schedule:
         raise UserFacingGraphQLError(
-            graphene_info.schema.type_named("ScheduleDefinitionNotFoundError")(
+            graphene_info.schema.type_named("ScheduleNotFoundError")(
                 schedule_name=schedule_selector.schedule_name
             )
         )
 
-    return graphene_info.schema.type_named("ScheduleDefinition")(
+    return graphene_info.schema.type_named("Schedule")(
         graphene_info, external_schedule=external_schedule
     )
 
 
-def get_schedule_config(graphene_info, external_schedule):
-    check.inst_param(external_schedule, "external_schedule", ExternalSchedule)
-    handle = external_schedule.handle.repository_handle
+def get_schedule_next_tick(graphene_info, schedule_state):
+    if schedule_state.status != JobStatus.RUNNING:
+        return None
 
-    result = graphene_info.context.get_external_schedule_execution_data(
-        handle, external_schedule.name
+    repository_origin = schedule_state.origin.external_repository_origin
+    if not graphene_info.context.has_repository_location(
+        repository_origin.repository_location_origin.location_name
+    ):
+        return None
+    repository_location = graphene_info.context.get_repository_location(
+        repository_origin.repository_location_origin.location_name
     )
-    if isinstance(result, ExternalScheduleExecutionData):
-        run_config_yaml = yaml.safe_dump(result.run_config, default_flow_style=False)
-        return graphene_info.schema.type_named("ScheduleRunConfig")(
-            yaml=run_config_yaml if run_config_yaml else ""
-        )
-    else:
-        return graphene_info.schema.type_named("PythonError")(result.error)
+    if not repository_location.has_repository(repository_origin.repository_name):
+        return None
+
+    repository = repository_location.get_repository(repository_origin.repository_name)
+    external_schedule = repository.get_external_job(schedule_state.name)
+    time_iter = external_schedule.execution_time_iterator(
+        get_timestamp_from_utc_datetime(get_current_datetime_in_utc())
+    )
+
+    next_timestamp = next(time_iter).timestamp()
+    return graphene_info.schema.type_named("FutureJobTick")(schedule_state, next_timestamp)
