@@ -1,5 +1,3 @@
-from __future__ import absolute_import
-
 from dagster_graphql import dauphin
 
 
@@ -13,12 +11,14 @@ def create_schema():
         errors,
         execution,
         external,
+        jobs,
         paging,
         partition_sets,
         pipelines,
         roots,
         runs,
         schedules,
+        sensors,
     )
 
     return dauphin.create_schema()
