@@ -1,11 +1,13 @@
 from dagster import check
 from dagster.core.host_representation import ExternalPartitionSet, RepositoryHandle
 from dagster.core.storage.pipeline_run import PipelineRunsFilter
+from dagster.core.storage.tags import PARTITION_NAME_TAG, PARTITION_SET_TAG
 from dagster.utils import merge_dicts
 from dagster_graphql import dauphin
 from dagster_graphql.implementation.fetch_partition_sets import (
     get_partition_by_name,
     get_partition_config,
+    get_partition_set_partition_statuses,
     get_partition_tags,
     get_partitions,
 )
@@ -18,7 +20,7 @@ from dagster_graphql.schema.errors import (
 
 
 class DauphinPartition(dauphin.ObjectType):
-    class Meta(object):
+    class Meta:
         name = "Partition"
 
     name = dauphin.NonNull(dauphin.String)
@@ -33,6 +35,7 @@ class DauphinPartition(dauphin.ObjectType):
         cursor=dauphin.String(),
         limit=dauphin.Int(),
     )
+    status = dauphin.Field("PipelineRunStatus")
 
     def __init__(self, external_repository_handle, external_partition_set, partition_name):
         self._external_repository_handle = check.inst_param(
@@ -69,15 +72,15 @@ class DauphinPartition(dauphin.ObjectType):
     def resolve_runs(self, graphene_info, **kwargs):
         filters = kwargs.get("filter")
         partition_tags = {
-            "dagster/partition_set": self._external_partition_set.name,
-            "dagster/partition": self._partition_name,
+            PARTITION_SET_TAG: self._external_partition_set.name,
+            PARTITION_NAME_TAG: self._partition_name,
         }
         if filters is not None:
             filters = filters.to_selector()
             runs_filter = PipelineRunsFilter(
                 run_ids=filters.run_ids,
                 pipeline_name=filters.pipeline_name,
-                status=filters.status,
+                statuses=filters.statuses,
                 tags=merge_dicts(filters.tags, partition_tags),
             )
         else:
@@ -89,16 +92,17 @@ class DauphinPartition(dauphin.ObjectType):
 
 
 class DauphinPartitions(dauphin.ObjectType):
-    class Meta(object):
+    class Meta:
         name = "Partitions"
 
     results = dauphin.non_null_list("Partition")
 
 
 class DauphinPartitionSet(dauphin.ObjectType):
-    class Meta(object):
+    class Meta:
         name = "PartitionSet"
 
+    id = dauphin.NonNull(dauphin.ID)
     name = dauphin.NonNull(dauphin.String)
     pipeline_name = dauphin.NonNull(dauphin.String)
     solid_selection = dauphin.List(dauphin.NonNull(dauphin.String))
@@ -110,6 +114,7 @@ class DauphinPartitionSet(dauphin.ObjectType):
         reverse=dauphin.Boolean(),
     )
     partition = dauphin.Field("Partition", partition_name=dauphin.NonNull(dauphin.String))
+    partitionStatusesOrError = dauphin.NonNull("PartitionStatusesOrError")
 
     def __init__(self, external_repository_handle, external_partition_set):
         self._external_repository_handle = check.inst_param(
@@ -126,6 +131,9 @@ class DauphinPartitionSet(dauphin.ObjectType):
             mode=external_partition_set.mode,
         )
 
+    def resolve_id(self, _graphene_info):
+        return self._external_partition_set.get_external_origin_id()
+
     def resolve_partitionsOrError(self, graphene_info, **kwargs):
         return get_partitions(
             graphene_info,
@@ -144,53 +152,80 @@ class DauphinPartitionSet(dauphin.ObjectType):
             partition_name,
         )
 
+    def resolve_partitionStatusesOrError(self, graphene_info):
+        return get_partition_set_partition_statuses(
+            graphene_info, self._external_repository_handle, self._external_partition_set.name
+        )
+
 
 class DapuphinPartitionSetOrError(dauphin.Union):
-    class Meta(object):
+    class Meta:
         name = "PartitionSetOrError"
         types = ("PartitionSet", DauphinPartitionSetNotFoundError, DauphinPythonError)
 
 
 class DauphinPartitionSets(dauphin.ObjectType):
-    class Meta(object):
+    class Meta:
         name = "PartitionSets"
 
     results = dauphin.non_null_list("PartitionSet")
 
 
 class DauphinPartitionTags(dauphin.ObjectType):
-    class Meta(object):
+    class Meta:
         name = "PartitionTags"
 
     results = dauphin.non_null_list("PipelineTag")
 
 
 class DauphinPartitionRunConfig(dauphin.ObjectType):
-    class Meta(object):
+    class Meta:
         name = "PartitionRunConfig"
 
     yaml = dauphin.NonNull(dauphin.String)
 
 
 class DauphinPartitionSetsOrError(dauphin.Union):
-    class Meta(object):
+    class Meta:
         name = "PartitionSetsOrError"
         types = (DauphinPartitionSets, DauphinPipelineNotFoundError, DauphinPythonError)
 
 
 class DauphinPartitionsOrError(dauphin.Union):
-    class Meta(object):
+    class Meta:
         name = "PartitionsOrError"
         types = (DauphinPartitions, DauphinPythonError)
 
 
 class DauphinPartitionTagsOrError(dauphin.Union):
-    class Meta(object):
+    class Meta:
         name = "PartitionTagsOrError"
         types = (DauphinPartitionTags, DauphinPythonError)
 
 
 class DauphinPartitionRunConfigOrError(dauphin.Union):
-    class Meta(object):
+    class Meta:
         name = "PartitionRunConfigOrError"
         types = (DauphinPartitionRunConfig, DauphinPythonError)
+
+
+class DauphinPartitionStatus(dauphin.ObjectType):
+    class Meta:
+        name = "PartitionStatus"
+
+    id = dauphin.NonNull(dauphin.String)
+    partitionName = dauphin.NonNull(dauphin.String)
+    runStatus = dauphin.Field("PipelineRunStatus")
+
+
+class DauphinPartitionStatuses(dauphin.ObjectType):
+    class Meta:
+        name = "PartitionStatuses"
+
+    results = dauphin.non_null_list("PartitionStatus")
+
+
+class DauphinPartitionStatusesOrError(dauphin.Union):
+    class Meta:
+        name = "PartitionStatusesOrError"
+        types = (DauphinPartitionStatuses, DauphinPythonError)
