@@ -1,10 +1,13 @@
 import sys
+from contextlib import contextmanager
 
 from dagster import check
 from dagster.cli.workspace import Workspace
-from dagster.core.code_pointer import CodePointer
-from dagster.core.host_representation import RepositoryLocationHandle
-from dagster.core.host_representation.handle import UserProcessApi
+from dagster.core.definitions.reconstructable import ReconstructableRepository
+from dagster.core.host_representation import (
+    InProcessRepositoryLocationOrigin,
+    ManagedGrpcPythonEnvRepositoryLocationOrigin,
+)
 from dagster.core.instance import DagsterInstance
 from dagster.core.types.loadable_target_origin import LoadableTargetOrigin
 from dagster_graphql.implementation.context import DagsterGraphQLContext
@@ -53,8 +56,8 @@ def define_in_process_context(python_file, fn_name, instance):
     return DagsterGraphQLContext(
         workspace=Workspace(
             [
-                RepositoryLocationHandle.create_in_process_location(
-                    CodePointer.from_python_file(python_file, fn_name, None)
+                InProcessRepositoryLocationOrigin(
+                    ReconstructableRepository.for_file(python_file, fn_name)
                 )
             ]
         ),
@@ -62,23 +65,23 @@ def define_in_process_context(python_file, fn_name, instance):
     )
 
 
+@contextmanager
 def define_out_of_process_context(python_file, fn_name, instance):
     check.inst_param(instance, "instance", DagsterInstance)
 
-    return DagsterGraphQLContext(
-        workspace=Workspace(
-            [
-                RepositoryLocationHandle.create_python_env_location(
-                    loadable_target_origin=LoadableTargetOrigin(
-                        executable_path=sys.executable, python_file=python_file, attribute=fn_name,
-                    ),
-                    location_name=main_repo_location_name(),
-                    user_process_api=UserProcessApi.CLI,
-                )
-            ]
-        ),
-        instance=instance,
-    )
+    with Workspace(
+        [
+            ManagedGrpcPythonEnvRepositoryLocationOrigin(
+                loadable_target_origin=LoadableTargetOrigin(
+                    executable_path=sys.executable, python_file=python_file, attribute=fn_name,
+                ),
+                location_name=main_repo_location_name(),
+            )
+        ]
+    ) as workspace:
+        yield DagsterGraphQLContext(
+            workspace=workspace, instance=instance,
+        )
 
 
 def infer_repository(graphql_context):
@@ -120,3 +123,15 @@ def infer_schedule_selector(graphql_context, schedule_name):
     selector = infer_repository_selector(graphql_context)
     selector.update({"scheduleName": schedule_name})
     return selector
+
+
+def infer_sensor_selector(graphql_context, sensor_name):
+    selector = infer_repository_selector(graphql_context)
+    selector.update({"sensorName": sensor_name})
+    return selector
+
+
+def infer_job_selector(graphql_context, job_name):
+    selector = infer_repository_selector(graphql_context)
+    selector.update({"jobName": job_name})
+    return selector
