@@ -4,6 +4,7 @@ import logging
 import os
 import time
 from collections import OrderedDict
+from contextlib import contextmanager
 from copy import deepcopy
 
 from dagster import (
@@ -45,15 +46,17 @@ from dagster import (
     usable_as_dagster_type,
     weekly_schedule,
 )
-from dagster.cli.workspace.load import location_handle_from_python_file
-from dagster.core.definitions.decorators import job
+from dagster.cli.workspace.load import location_origin_from_python_file
+from dagster.core.definitions.decorators.sensor import sensor
 from dagster.core.definitions.partition import last_empty_partition
 from dagster.core.definitions.reconstructable import ReconstructableRepository
-from dagster.core.host_representation import RepositoryLocation
-from dagster.core.host_representation.handle import python_user_process_api_from_instance
+from dagster.core.definitions.sensor import RunRequest, SkipReason
+from dagster.core.host_representation import RepositoryLocation, RepositoryLocationHandle
 from dagster.core.log_manager import coerce_valid_log_level
 from dagster.core.storage.tags import RESUME_RETRY_TAG
 from dagster.core.test_utils import today_at_midnight
+from dagster.experimental import DynamicOutput, DynamicOutputDefinition
+from dagster.seven import get_system_temp_directory
 from dagster.utils import file_relative_path, segfault
 from dagster_graphql.test.utils import (
     define_in_process_context,
@@ -88,9 +91,11 @@ PoorMansDataFrame = PythonObjectDagsterType(
 )
 
 
+@contextmanager
 def define_test_out_of_process_context(instance):
     check.inst_param(instance, "instance", DagsterInstance)
-    return define_out_of_process_context(__file__, main_repo_name(), instance)
+    with define_out_of_process_context(__file__, main_repo_name(), instance) as context:
+        yield context
 
 
 def define_test_in_process_context(instance):
@@ -102,16 +107,17 @@ def create_main_recon_repo():
     return ReconstructableRepository.for_file(__file__, main_repo_name())
 
 
-def get_main_external_repo(instance):
-    return RepositoryLocation.from_handle(
-        location_handle_from_python_file(
+@contextmanager
+def get_main_external_repo():
+    with RepositoryLocationHandle.create_from_repository_location_origin(
+        location_origin_from_python_file(
             python_file=file_relative_path(__file__, "setup.py"),
             attribute=main_repo_name(),
             working_directory=None,
-            user_process_api=python_user_process_api_from_instance(instance),
             location_name=main_repo_location_name(),
         )
-    ).get_repository(main_repo_name())
+    ) as handle:
+        yield RepositoryLocation.from_handle(handle).get_repository(main_repo_name())
 
 
 @lambda_solid(
@@ -159,7 +165,7 @@ def csv_hello_world_solids_config_fs_storage():
         "solids": {
             "sum_solid": {"inputs": {"num": file_relative_path(__file__, "../data/num.csv")}}
         },
-        "storage": {"filesystem": {}},
+        "intermediate_storage": {"filesystem": {}},
     }
 
 
@@ -622,7 +628,7 @@ def spew_pipeline():
 def retry_config(count):
     return {
         "resources": {"retry_count": {"config": {"count": count}}},
-        "storage": {"filesystem": {}},
+        "intermediate_storage": {"filesystem": {}},
     }
 
 
@@ -792,13 +798,42 @@ def retry_multi_input_early_terminate_pipeline():
     sum_inputs(input_one=get_input_one(step_one), input_two=get_input_two(step_one))
 
 
+@pipeline
+def dynamic_pipeline():
+    @solid
+    def multiply_by_two(context, y):
+        context.log.info("multiply_by_two is returning " + str(y * 2))
+        return y * 2
+
+    @solid
+    def multiply_inputs(context, y, ten, should_fail):
+        current_run = context.instance.get_run_by_id(context.run_id)
+        if should_fail:
+            if y == 2 and current_run.parent_run_id is None:
+                raise Exception()
+        context.log.info("multiply_inputs is returning " + str(y * ten))
+        return y * ten
+
+    @solid
+    def emit_ten(_):
+        return 10
+
+    @solid(output_defs=[DynamicOutputDefinition()])
+    def emit(_):
+        for i in range(3):
+            yield DynamicOutput(value=i, mapping_key=str(i))
+
+    # pylint: disable=no-member
+    emit().map(lambda n: multiply_by_two(multiply_inputs(n, emit_ten())))
+
+
 def get_retry_multi_execution_params(graphql_context, should_fail, retry_id=None):
     selector = infer_pipeline_selector(graphql_context, "retry_multi_output_pipeline")
     return {
         "mode": "default",
         "selector": selector,
         "runConfigData": {
-            "storage": {"filesystem": {}},
+            "intermediate_storage": {"filesystem": {}},
             "solids": {"can_fail": {"config": {"fail": should_fail}}},
         },
         "executionMetadata": {
@@ -814,7 +849,7 @@ def define_schedules():
         name="scheduled_integer_partitions",
         pipeline_name="no_config_pipeline",
         partition_fn=lambda: [Partition(x) for x in range(1, 10)],
-        run_config_fn_for_partition=lambda _partition: {"storage": {"filesystem": {}}},
+        run_config_fn_for_partition=lambda _partition: {"intermediate_storage": {"filesystem": {}}},
         tags_fn_for_partition=lambda _partition: {"test": "1234"},
     )
 
@@ -822,21 +857,21 @@ def define_schedules():
         name="no_config_pipeline_hourly_schedule",
         cron_schedule="0 0 * * *",
         pipeline_name="no_config_pipeline",
-        run_config={"storage": {"filesystem": {}}},
+        run_config={"intermediate_storage": {"filesystem": {}}},
     )
 
     no_config_pipeline_hourly_schedule_with_config_fn = ScheduleDefinition(
         name="no_config_pipeline_hourly_schedule_with_config_fn",
         cron_schedule="0 0 * * *",
         pipeline_name="no_config_pipeline",
-        run_config_fn=lambda _context: {"storage": {"filesystem": {}}},
+        run_config_fn=lambda _context: {"intermediate_storage": {"filesystem": {}}},
     )
 
     no_config_should_execute = ScheduleDefinition(
         name="no_config_should_execute",
         cron_schedule="0 0 * * *",
         pipeline_name="no_config_pipeline",
-        run_config={"storage": {"filesystem": {}}},
+        run_config={"intermediate_storage": {"filesystem": {}}},
         should_execute=lambda _context: False,
     )
 
@@ -844,108 +879,111 @@ def define_schedules():
         name="dynamic_config",
         cron_schedule="0 0 * * *",
         pipeline_name="no_config_pipeline",
-        run_config_fn=lambda _context: {"storage": {"filesystem": {}}},
+        run_config_fn=lambda _context: {"intermediate_storage": {"filesystem": {}}},
     )
 
     partition_based = integer_partition_set.create_schedule_definition(
-        schedule_name="partition_based", cron_schedule="0 0 * * *",
-    )
-
-    partition_based_custom_selector = integer_partition_set.create_schedule_definition(
-        schedule_name="partition_based_custom_selector",
+        schedule_name="partition_based",
         cron_schedule="0 0 * * *",
         partition_selector=last_empty_partition,
     )
 
     @daily_schedule(
         pipeline_name="no_config_pipeline",
-        start_date=today_at_midnight() - datetime.timedelta(days=1),
+        start_date=today_at_midnight().subtract(days=1),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=2)).time(),
     )
     def partition_based_decorator(_date):
-        return {"storage": {"filesystem": {}}}
+        return {"intermediate_storage": {"filesystem": {}}}
 
     @daily_schedule(
         pipeline_name="multi_mode_with_loggers",
-        start_date=today_at_midnight() - datetime.timedelta(days=1),
+        start_date=today_at_midnight().subtract(days=1),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=2)).time(),
         mode="foo_mode",
     )
     def partition_based_multi_mode_decorator(_date):
-        return {"storage": {"filesystem": {}}}
+        return {"intermediate_storage": {"filesystem": {}}}
 
     @hourly_schedule(
         pipeline_name="no_config_chain_pipeline",
-        start_date=today_at_midnight() - datetime.timedelta(days=1),
+        start_date=today_at_midnight().subtract(days=1),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=2)).time(),
         solid_selection=["return_foo"],
     )
     def solid_selection_hourly_decorator(_date):
-        return {"storage": {"filesystem": {}}}
+        return {"intermediate_storage": {"filesystem": {}}}
 
     @daily_schedule(
         pipeline_name="no_config_chain_pipeline",
-        start_date=today_at_midnight() - datetime.timedelta(days=2),
+        start_date=today_at_midnight().subtract(days=2),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=3)).time(),
         solid_selection=["return_foo"],
     )
     def solid_selection_daily_decorator(_date):
-        return {"storage": {"filesystem": {}}}
+        return {"intermediate_storage": {"filesystem": {}}}
 
     @monthly_schedule(
         pipeline_name="no_config_chain_pipeline",
-        start_date=(today_at_midnight() - datetime.timedelta(days=100)).replace(day=1),
+        start_date=(today_at_midnight().subtract(days=100)).replace(day=1),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=4)).time(),
         solid_selection=["return_foo"],
     )
     def solid_selection_monthly_decorator(_date):
-        return {"storage": {"filesystem": {}}}
+        return {"intermediate_storage": {"filesystem": {}}}
 
     @weekly_schedule(
         pipeline_name="no_config_chain_pipeline",
-        start_date=today_at_midnight() - datetime.timedelta(days=50),
+        start_date=today_at_midnight().subtract(days=50),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=5)).time(),
         solid_selection=["return_foo"],
     )
     def solid_selection_weekly_decorator(_date):
-        return {"storage": {"filesystem": {}}}
+        return {"intermediate_storage": {"filesystem": {}}}
 
     # Schedules for testing the user error boundary
     @daily_schedule(
         pipeline_name="no_config_pipeline",
-        start_date=today_at_midnight() - datetime.timedelta(days=1),
+        start_date=today_at_midnight().subtract(days=1),
         should_execute=lambda _: asdf,  # pylint: disable=undefined-variable
     )
     def should_execute_error_schedule(_date):
-        return {"storage": {"filesystem": {}}}
+        return {"intermediate_storage": {"filesystem": {}}}
 
     @daily_schedule(
         pipeline_name="no_config_pipeline",
-        start_date=today_at_midnight() - datetime.timedelta(days=1),
+        start_date=today_at_midnight().subtract(days=1),
         tags_fn_for_date=lambda _: asdf,  # pylint: disable=undefined-variable
     )
     def tags_error_schedule(_date):
-        return {"storage": {"filesystem": {}}}
+        return {"intermediate_storage": {"filesystem": {}}}
 
     @daily_schedule(
-        pipeline_name="no_config_pipeline",
-        start_date=today_at_midnight() - datetime.timedelta(days=1),
+        pipeline_name="no_config_pipeline", start_date=today_at_midnight().subtract(days=1),
     )
     def run_config_error_schedule(_date):
         return asdf  # pylint: disable=undefined-variable
 
+    @daily_schedule(
+        pipeline_name="no_config_pipeline",
+        start_date=today_at_midnight("US/Central") - datetime.timedelta(days=1),
+        execution_timezone="US/Central",
+    )
+    def timezone_schedule(_date):
+        return {"intermediate_storage": {"filesystem": {}}}
+
     tagged_pipeline_schedule = ScheduleDefinition(
         name="tagged_pipeline_schedule",
         cron_schedule="0 0 * * *",
         pipeline_name="tagged_pipeline",
-        run_config={"storage": {"filesystem": {}}},
+        run_config={"intermediate_storage": {"filesystem": {}}},
     )
 
     tagged_pipeline_override_schedule = ScheduleDefinition(
         name="tagged_pipeline_override_schedule",
         cron_schedule="0 0 * * *",
         pipeline_name="tagged_pipeline",
-        run_config={"storage": {"filesystem": {}}},
+        run_config={"intermediate_storage": {"filesystem": {}}},
         tags={"foo": "notbar"},
     )
 
@@ -963,7 +1001,6 @@ def define_schedules():
         no_config_should_execute,
         dynamic_config,
         partition_based,
-        partition_based_custom_selector,
         partition_based_decorator,
         partition_based_multi_mode_decorator,
         solid_selection_hourly_decorator,
@@ -974,6 +1011,7 @@ def define_schedules():
         tagged_pipeline_schedule,
         tagged_pipeline_override_schedule,
         tags_error_schedule,
+        timezone_schedule,
         invalid_config_schedule,
     ]
 
@@ -985,7 +1023,7 @@ def define_partitions():
         solid_selection=["return_hello"],
         mode="default",
         partition_fn=lambda: [Partition(i) for i in range(10)],
-        run_config_fn_for_partition=lambda _: {"storage": {"filesystem": {}}},
+        run_config_fn_for_partition=lambda _: {"intermediate_storage": {"filesystem": {}}},
         tags_fn_for_partition=lambda partition: {"foo": partition.name},
     )
 
@@ -993,7 +1031,7 @@ def define_partitions():
         name="enum_partition",
         pipeline_name="noop_pipeline",
         partition_fn=lambda: ["one", "two", "three"],
-        run_config_fn_for_partition=lambda _: {"storage": {"filesystem": {}}},
+        run_config_fn_for_partition=lambda _: {"intermediate_storage": {"filesystem": {}}},
     )
 
     chained_partition_set = PartitionSetDefinition(
@@ -1001,18 +1039,44 @@ def define_partitions():
         pipeline_name="chained_failure_pipeline",
         mode="default",
         partition_fn=lambda: [Partition(i) for i in range(10)],
-        run_config_fn_for_partition=lambda _: {"storage": {"filesystem": {}}},
+        run_config_fn_for_partition=lambda _: {"intermediate_storage": {"filesystem": {}}},
     )
 
     return [integer_set, enum_set, chained_partition_set]
 
 
-def define_jobs():
-    @job(pipeline_name="no_config_pipeline")
-    def job_no_config(_):
-        return {"storage": {"filesystem": {}}}
+def define_sensors():
+    @sensor(pipeline_name="no_config_pipeline", mode="default")
+    def always_no_config_sensor(_):
+        return RunRequest(
+            run_key=None,
+            run_config={"intermediate_storage": {"filesystem": {}}},
+            tags={"test": "1234"},
+        )
 
-    return [job_no_config]
+    @sensor(pipeline_name="no_config_pipeline", mode="default")
+    def once_no_config_sensor(_):
+        return RunRequest(
+            run_key="once",
+            run_config={"intermediate_storage": {"filesystem": {}}},
+            tags={"test": "1234"},
+        )
+
+    @sensor(pipeline_name="no_config_pipeline", mode="default")
+    def never_no_config_sensor(_):
+        return SkipReason("never")
+
+    @sensor(pipeline_name="no_config_pipeline", mode="default")
+    def multi_no_config_sensor(_):
+        yield RunRequest(run_key="A")
+        yield RunRequest(run_key="B")
+
+    return [
+        always_no_config_sensor,
+        once_no_config_sensor,
+        never_no_config_sensor,
+        multi_no_config_sensor,
+    ]
 
 
 @pipeline
@@ -1023,7 +1087,9 @@ def chained_failure_pipeline():
 
     @lambda_solid
     def conditionally_fail(_):
-        if os.environ.get("TEST_SOLID_SHOULD_FAIL"):
+        if os.path.isfile(
+            os.path.join(get_system_temp_directory(), "chained_failure_pipeline_conditionally_fail")
+        ):
             raise Exception("blah")
 
         return "hello"
@@ -1077,8 +1143,9 @@ def test_repo():
             spew_pipeline,
             tagged_pipeline,
             chained_failure_pipeline,
+            dynamic_pipeline,
         ]
         + define_schedules()
+        + define_sensors()
         + define_partitions()
-        + define_jobs()
     )
