@@ -3,6 +3,7 @@ import copy
 from dagster import execute_pipeline, lambda_solid, pipeline, repository
 from dagster.core.definitions.pipeline_base import InMemoryPipeline
 from dagster.core.execution.api import execute_run
+from dagster.core.storage.pipeline_run import PipelineRunStatus
 from dagster.core.storage.tags import PARENT_RUN_ID_TAG, ROOT_RUN_ID_TAG
 from dagster.core.test_utils import instance_for_test
 from dagster_graphql.test.utils import (
@@ -30,6 +31,14 @@ query PipelineRunsRootQuery($selector: PipelineSelector!) {
 fragment RunHistoryRunFragment on PipelineRun {
   runId
   status
+  repositoryOrigin {
+    repositoryLocationName
+    repositoryName
+    repositoryLocationMetadata {
+      key
+      value
+    }
+  }
   pipeline {
     ...on PipelineReference { name }
   }
@@ -106,6 +115,16 @@ query PipelineRunsRootQuery($filter: PipelineRunsFilter!) {
 }
 """
 
+FILTERED_RUN_COUNT_QUERY = """
+query PipelineRunsRootQuery($filter: PipelineRunsFilter!) {
+  pipelineRunsOrError(filter: $filter) {
+    ... on PipelineRuns {
+      count
+    }
+  }
+}
+"""
+
 
 RUN_GROUP_QUERY = """
 query RunGroupQuery($runId: ID!) {
@@ -198,6 +217,12 @@ class TestGetRuns(ExecutingGraphQLContextTestMatrix):
         assert tags[0]["key"] == "fruit"
         assert tags[0]["value"] == "apple"
 
+        origin = runs[0]["repositoryOrigin"]
+        assert origin
+        assert origin["repositoryLocationName"] == selector["repositoryLocationName"]
+        assert origin["repositoryName"] == selector["repositoryName"]
+        assert origin["repositoryLocationMetadata"]
+
         payload_two = sync_execute_get_run_log_data(
             context=graphql_context,
             variables={
@@ -511,12 +536,12 @@ def test_filtered_runs():
         run_id_1 = execute_pipeline(
             repo.get_pipeline("foo_pipeline"), instance=instance, tags={"run": "one"}
         ).run_id
-        _run_id_2 = execute_pipeline(
+        run_id_2 = execute_pipeline(
             repo.get_pipeline("foo_pipeline"), instance=instance, tags={"run": "two"}
         ).run_id
         with define_out_of_process_context(__file__, "get_repo_at_time_1", instance) as context:
             result = execute_dagster_graphql(
-                context, FILTERED_RUN_QUERY, variables={"filter": {"runId": run_id_1}}
+                context, FILTERED_RUN_QUERY, variables={"filter": {"runIds": [run_id_1]}}
             )
             assert result.data
             run_ids = [run["runId"] for run in result.data["pipelineRunsOrError"]["results"]]
@@ -533,6 +558,77 @@ def test_filtered_runs():
             assert len(run_ids) == 1
             assert run_ids[0] == run_id_1
 
+            # test multiple run ids
+            result = execute_dagster_graphql(
+                context, FILTERED_RUN_QUERY, variables={"filter": {"runIds": [run_id_1, run_id_2]}}
+            )
+            assert result.data
+            run_ids = [run["runId"] for run in result.data["pipelineRunsOrError"]["results"]]
+            assert len(run_ids) == 2
+            assert set(run_ids) == set([run_id_1, run_id_2])
+
+
+def test_filtered_runs_status():
+    with instance_for_test() as instance:
+        repo = get_repo_at_time_1()
+        _ = instance.create_run_for_pipeline(
+            repo.get_pipeline("foo_pipeline"), status=PipelineRunStatus.STARTED
+        ).run_id
+        run_id_2 = instance.create_run_for_pipeline(
+            repo.get_pipeline("foo_pipeline"), status=PipelineRunStatus.FAILURE
+        ).run_id
+        with define_out_of_process_context(__file__, "get_repo_at_time_1", instance) as context:
+            result = execute_dagster_graphql(
+                context, FILTERED_RUN_QUERY, variables={"filter": {"statuses": ["FAILURE"]}}
+            )
+            assert result.data
+            run_ids = [run["runId"] for run in result.data["pipelineRunsOrError"]["results"]]
+            assert len(run_ids) == 1
+            assert run_ids[0] == run_id_2
+
+
+def test_filtered_runs_multiple_statuses():
+    with instance_for_test() as instance:
+        repo = get_repo_at_time_1()
+        _ = instance.create_run_for_pipeline(
+            repo.get_pipeline("foo_pipeline"), status=PipelineRunStatus.STARTED
+        ).run_id
+        run_id_2 = instance.create_run_for_pipeline(
+            repo.get_pipeline("foo_pipeline"), status=PipelineRunStatus.FAILURE
+        ).run_id
+        run_id_3 = instance.create_run_for_pipeline(
+            repo.get_pipeline("foo_pipeline"), status=PipelineRunStatus.SUCCESS
+        ).run_id
+        with define_out_of_process_context(__file__, "get_repo_at_time_1", instance) as context:
+            result = execute_dagster_graphql(
+                context,
+                FILTERED_RUN_QUERY,
+                variables={"filter": {"statuses": ["FAILURE", "SUCCESS"]}},
+            )
+            assert result.data
+            run_ids = [run["runId"] for run in result.data["pipelineRunsOrError"]["results"]]
+            assert len(run_ids) == 2
+            assert run_id_2 in run_ids
+            assert run_id_3 in run_ids
+
+
+def test_filtered_runs_count():
+    with instance_for_test() as instance:
+        repo = get_repo_at_time_1()
+        instance.create_run_for_pipeline(  # pylint: disable=expression-not-assigned
+            repo.get_pipeline("foo_pipeline"), status=PipelineRunStatus.STARTED
+        ).run_id
+        instance.create_run_for_pipeline(  # pylint: disable=expression-not-assigned
+            repo.get_pipeline("foo_pipeline"), status=PipelineRunStatus.FAILURE
+        ).run_id
+        with define_out_of_process_context(__file__, "get_repo_at_time_1", instance) as context:
+            result = execute_dagster_graphql(
+                context, FILTERED_RUN_COUNT_QUERY, variables={"filter": {"statuses": ["FAILURE"]}}
+            )
+            assert result.data
+            count = result.data["pipelineRunsOrError"]["count"]
+            assert count == 1
+
 
 def test_run_group():
     with instance_for_test() as instance:
